labeltools.label_logical_ties_in_expr_with_logical_tie_durations
================================================================

.. autofunction:: abjad.tools.labeltools.label_logical_ties_in_expr_with_logical_tie_durations.label_logical_ties_in_expr_with_logical_tie_durations
